@@ -1,3 +1,3 @@
 from edgeimpulse import runner
 from edgeimpulse import audio
-from edgeimpulse import camera
+from edgeimpulse import image
