@@ -4,6 +4,7 @@ import numpy as np
 import cv2
 from edgeimpulse.runner import ImpulseRunner
 import time
+import psutil
 
 class ImageImpulseRunner(ImpulseRunner):
     def __init__(self, model_path: str):
@@ -15,8 +16,11 @@ class ImageImpulseRunner(ImpulseRunner):
         self.isGrayscale = False
 
     def init(self):
-        model_info = super(ImageImpulseRunner, self).init()
+        if psutil.OSX or psutil.MACOS:
+            print('Make sure that video devices access is granted for your application')
+            print('If your video device is not responding, try running "tccutil reset Camera" to reset the camera access privileges')
 
+        model_info = super(ImageImpulseRunner, self).init()
         width = model_info['model_parameters']['image_input_width'];
         height = model_info['model_parameters']['image_input_height'];
 
@@ -29,14 +33,9 @@ class ImageImpulseRunner(ImpulseRunner):
         return model_info
 
     def __enter__(self):
-        try:
-            self.videoCapture = cv2.VideoCapture(0)
-            if self.videoCapture is None or not self.videoCapture.isOpened():
-                raise Exception('Unable to open video device. Check your permission settings')
-            self.closed = False
-            return self
-        except:
-            raise Exception('Unable to open video device. Check your permission settings')
+        self.videoCapture = cv2.VideoCapture()
+        self.closed = False
+        return self
 
     def __exit__(self, type, value, traceback):
         self.videoCapture.release()
@@ -45,12 +44,12 @@ class ImageImpulseRunner(ImpulseRunner):
     def classify(self, data):
         return super(ImageImpulseRunner, self).classify(data)
 
-    def classifier(self):
-        while not self.closed and self.videoCapture.isOpened():
-            ret, img = self.videoCapture.read()
-            if ret:
+    def classifier(self, videoDeviceId = 0):
+        self.videoCapture = cv2.VideoCapture(videoDeviceId)
+        while not self.closed:
+            success, img = self.videoCapture.read()
+            if success:
                 features = []
-
                 if self.isGrayscale:
                     img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
                     resizedImg = cv2.resize(img, self.dim, interpolation = cv2.INTER_AREA)
